import { dataSource } from "../../data-source";
import { api } from "../../entity/user/api";
import InternalException from "../../exceptions/internalException";

export default abstract class ApiService {
  /**
   * @description get apis
   * @returns {Promise<Array<api>>}
   */
  static async getAll(): Promise<Array<api>> {
    return await dataSource
      .getRepository(api)
      .createQueryBuilder("api")
      .leftJoinAndSelect("api.permissions", "permissions")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("apis not found", err);
      });
  }

  /**
   * @description get api by id
   * @param id number
   * @returns {Promise<api>}
   */
  static async getById(id: number): Promise<api> {
    return await dataSource
      .getRepository(api)
      .createQueryBuilder("api")
      .leftJoinAndSelect("api.permissions", "permissions")
      .where("api.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("api not found by id", err);
      });
  }

  /**
   * @description get api by token
   * @param token string
   * @returns {Promise<api>}
   */
  static async getByToken(token: string): Promise<api> {
    return await dataSource
      .getRepository(api)
      .createQueryBuilder("api")
      .leftJoinAndSelect("api.permissions", "permissions")
      .where("api.token = :token", { token: token })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("api not found by token", err);
      });
  }

  /**
   * @description get api by id
   * @param id number
   * @returns {Promise<api>}
   */
  static async getTokenById(id: number): Promise<api> {
    return await dataSource
      .getRepository(api)
      .createQueryBuilder("api")
      .select("token")
      .where("api.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("api token not found by id", err);
      });
  }
}
